@@ -19,8 +19,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef DEFAULTS_H
-#define DEFAULTS_H
+#pragma once
 
 #define DEFAULT_LOG_FOLDER "/var/log"
 
@@ -34,4 +33,3 @@
  */
 #define NO_MODE_ICON "text-x-generic"
 
-#endif // _DEFAULTS_H
