@@ -24,45 +24,33 @@
 #include <QAction>
 #include <QHeaderView>
 
-#include <QSortFilterProxyModel>
-#include <QIcon>
 #include <KLocalizedString>
+#include <QIcon>
 
 #include "logging.h"
 
 #include "logViewColumn.h"
 
-#include "logViewWidgetItem.h"
 #include "logLine.h"
 #include "logViewModel.h"
+#include "logViewWidgetItem.h"
 
 #include "ksystemlogConfig.h"
 
-class LogViewWidgetPrivate
-{
-public:
-    LogViewModel *logViewModel;
-
-    QActionGroup *headersTogglingActions;
-};
-
 LogViewWidget::LogViewWidget(QWidget *parent)
     : QTreeWidget(parent)
-    , d(new LogViewWidgetPrivate())
 {
     // TODO Add this setWhatsThis() to all columns each time they change
     // setWhatThis(i18n("<p>This is the main view of KSystemLog. It displays the last lines of the selected
     // log. Please see the documentation to discovers the meaning of each icons and existing log.</p><p>Log
     // lines in <b>bold</b> are the last added to the list.</p>"));
 
-    QStringList headerLabels;
-    headerLabels.append(QStringLiteral("Date"));
-    headerLabels.append(QStringLiteral("Message"));
+    const QStringList headerLabels{i18n("Date"), i18n("Message")};
 
-    d->logViewModel = new LogViewModel(this);
-    d->headersTogglingActions = new QActionGroup(this);
-    d->headersTogglingActions->setExclusive(false);
-    connect(d->headersTogglingActions, &QActionGroup::triggered, this, &LogViewWidget::toggleHeader);
+    mLogViewModel = new LogViewModel(this);
+    mHeadersTogglingActions = new QActionGroup(this);
+    mHeadersTogglingActions->setExclusive(false);
+    connect(mHeadersTogglingActions, &QActionGroup::triggered, this, &LogViewWidget::toggleHeader);
 
     setHeaderLabels(headerLabels);
 
@@ -89,9 +77,7 @@ LogViewWidget::LogViewWidget(QWidget *parent)
 
 LogViewWidget::~LogViewWidget()
 {
-    delete d->logViewModel;
-
-    delete d;
+    delete mLogViewModel;
 }
 
 void LogViewWidget::setColumns(const LogViewColumns &columns)
@@ -106,13 +92,13 @@ void LogViewWidget::setColumns(const LogViewColumns &columns)
     sortItems(0, Qt::AscendingOrder);
 
     // Remove previous header actions
-    QListIterator<QAction *> it(d->headersTogglingActions->actions());
+    QListIterator<QAction *> it(mHeadersTogglingActions->actions());
     it.toBack();
     while (it.hasPrevious()) {
         QAction *action = it.previous();
 
         header()->removeAction(action);
-        d->headersTogglingActions->removeAction(action);
+        mHeadersTogglingActions->removeAction(action);
 
         delete action;
     }
@@ -120,24 +106,25 @@ void LogViewWidget::setColumns(const LogViewColumns &columns)
     // Add new actions
     int columnIndex = 0;
 
-    foreach (const LogViewColumn &column, columns.columns()) {
-        QAction *action = new QAction(this);
+    const auto columnsLst = columns.columns();
+    for (const LogViewColumn &column : columnsLst) {
+        auto action = new QAction(this);
         action->setText(column.columnName());
         // helloAction->setIcon(QIcon::fromTheme( QLatin1String( "media-playback-start" )));
-        // helloAction->setShortcut(Qt::CTRL + Qt::Key_M);
+        // helloAction->setShortcut(Qt::CTRL | Qt::Key_M);
         action->setCheckable(true);
         action->setChecked(true);
         action->setToolTip(i18n("Display/Hide the '%1' column", column.columnName()));
         action->setData(QVariant(columnIndex));
 
-        d->headersTogglingActions->addAction(action);
+        mHeadersTogglingActions->addAction(action);
 
         ++columnIndex;
     }
 
-    header()->addActions(d->headersTogglingActions->actions());
+    header()->addActions(mHeadersTogglingActions->actions());
 
-    emit columnsChanged(columns);
+    Q_EMIT columnsChanged(columns);
 
     logDebug() << "Log View Widget updated...";
 }
@@ -152,8 +139,9 @@ void LogViewWidget::resizeColumns()
 
 void LogViewWidget::selectAll()
 {
-    if (notHiddenItemCount() > 0)
+    if (notHiddenItemCount() > 0) {
         QTreeWidget::selectAll();
+    }
 }
 
 int LogViewWidget::itemCount() const
@@ -166,8 +154,8 @@ QList<LogLine *> LogViewWidget::logLines()
     QList<LogLine *> logLines;
 
     QTreeWidgetItemIterator it(this);
-    while (*it != nullptr) {
-        LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
+    while (*it) {
+        auto item = static_cast<LogViewWidgetItem *>(*it);
         logLines.append(item->logLine());
         ++it;
     }
@@ -180,9 +168,9 @@ LogViewWidgetItem *LogViewWidget::findNewestItem()
     LogViewWidgetItem *newestItem = nullptr;
 
     QTreeWidgetItemIterator it(this);
-    while (*it != nullptr) {
-        LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
-        if (newestItem == nullptr || newestItem->logLine()->isOlderThan(*(item->logLine()))) {
+    while (*it) {
+        auto item = static_cast<LogViewWidgetItem *>(*it);
+        if (!newestItem || newestItem->logLine()->isOlderThan(*(item->logLine()))) {
             newestItem = item;
         }
 
@@ -195,10 +183,11 @@ LogViewWidgetItem *LogViewWidget::findNewestItem()
 LogViewWidgetItem *LogViewWidget::findItem(LogLine *searchedLogLine)
 {
     QTreeWidgetItemIterator it(this);
-    while (*it != nullptr) {
-        LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
-        if (item->logLine()->equals(*searchedLogLine))
+    while (*it) {
+        auto item = static_cast<LogViewWidgetItem *>(*it);
+        if (item->logLine()->equals(*searchedLogLine)) {
             return item;
+        }
 
         ++it;
     }
@@ -211,7 +200,7 @@ QList<LogViewWidgetItem *> LogViewWidget::items()
     QList<LogViewWidgetItem *> items;
 
     QTreeWidgetItemIterator it(this);
-    while (*it != nullptr) {
+    while (*it) {
         items.append(static_cast<LogViewWidgetItem *>(*it));
         ++it;
     }
@@ -221,12 +210,12 @@ QList<LogViewWidgetItem *> LogViewWidget::items()
 
 LogViewModel *LogViewWidget::model() const
 {
-    return d->logViewModel;
+    return mLogViewModel;
 }
 
 bool LogViewWidget::hasItemsSelected()
 {
-    return (!selectedItems().isEmpty());
+    return !selectedItems().isEmpty();
 }
 
 LogViewWidgetItem *LogViewWidget::firstSelectedItem()
@@ -255,7 +244,7 @@ LogViewWidgetItem *LogViewWidget::lastSelectedItem()
 void LogViewWidget::expandAll()
 {
     QTreeWidgetItemIterator it(this);
-    while (*it != nullptr) {
+    while (*it) {
         expandItem(*it);
         ++it;
     }
@@ -264,7 +253,7 @@ void LogViewWidget::expandAll()
 void LogViewWidget::collapseAll()
 {
     QTreeWidgetItemIterator it(this);
-    while (*it != nullptr) {
+    while (*it) {
         collapseItem(*it);
         ++it;
     }
@@ -275,8 +264,8 @@ void LogViewWidget::toggleToolTip(bool enabled)
     logDebug() << "Toggle tool tip " << enabled;
 
     QTreeWidgetItemIterator it(this);
-    while (*it != nullptr) {
-        LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
+    while (*it) {
+        auto item = static_cast<LogViewWidgetItem *>(*it);
         item->toggleToolTip(enabled);
 
         ++it;
@@ -288,9 +277,9 @@ void LogViewWidget::scrollToNewestItem()
     logDebug() << "Scrolling to the newest item...";
 
     // Scroll to last item if requested
-    if (KSystemLogConfig::newLinesDisplayed() == true) {
+    if (KSystemLogConfig::newLinesDisplayed()) {
         LogViewWidgetItem *newestItem = findNewestItem();
-        if (newestItem != nullptr) {
+        if (newestItem) {
             scrollToItem(newestItem);
         }
     }
@@ -301,7 +290,7 @@ int LogViewWidget::notHiddenItemCount()
     int count = 0;
 
     QTreeWidgetItemIterator it(this, QTreeWidgetItemIterator::NotHidden);
-    while (*it != nullptr) {
+    while (*it) {
         count++;
         ++it;
     }
@@ -314,8 +303,9 @@ void LogViewWidget::toggleHeader(QAction *action)
     logDebug() << "Toggling header";
 
     int columnIndex = action->data().toInt();
-    if (header()->isSectionHidden(columnIndex) == true)
+    if (header()->isSectionHidden(columnIndex)) {
         header()->setSectionHidden(columnIndex, false);
-    else
+    } else {
         header()->setSectionHidden(columnIndex, true);
+    }
 }
