@@ -23,83 +23,67 @@
 
 #include <KLocalizedString>
 
-#include "logging.h"
 #include "defaults.h"
+#include "logging.h"
 
 #include "globals.h"
 
 #include "ksystemlogConfig.h"
-
-class GenericLogModeConfigurationPrivate
-{
-public:
-    QStringList logFilesPaths;
-
-    QList<int> logFilesLevels;
-};
-
 GenericLogModeConfiguration::GenericLogModeConfiguration(const QString &configurationGroup,
                                                          const QStringList &defaultLogFilesPaths,
                                                          const QList<int> &defaultLogFilesLevels)
-    : d(new GenericLogModeConfigurationPrivate())
 {
     logDebug() << "Using Configuration Group : " << configurationGroup;
-    configuration->setCurrentGroup(configurationGroup);
+    mConfiguration->setCurrentGroup(configurationGroup);
 
-    configuration->addItemStringList(QStringLiteral("LogFilesPaths"), d->logFilesPaths, defaultLogFilesPaths,
-                                     QStringLiteral("LogFilesPaths"));
+    mConfiguration->addItemStringList(QStringLiteral("LogFilesPaths"), mLogFilesPaths, defaultLogFilesPaths, QStringLiteral("LogFilesPaths"));
 
-    configuration->addItemIntList(QStringLiteral("LogFilesLevels"), d->logFilesLevels, defaultLogFilesLevels,
-                                  QStringLiteral("LogFilesLevels"));
+    mConfiguration->addItemIntList(QStringLiteral("LogFilesLevels"), mLogFilesLevels, defaultLogFilesLevels, QStringLiteral("LogFilesLevels"));
 }
 
 GenericLogModeConfiguration::~GenericLogModeConfiguration()
 {
-    delete d;
 }
 
 QStringList GenericLogModeConfiguration::logFilesPaths() const
 {
-    return d->logFilesPaths;
+    return mLogFilesPaths;
 }
 
 QList<int> GenericLogModeConfiguration::logFilesLevels() const
 {
-    return d->logFilesLevels;
+    return mLogFilesLevels;
 }
 
 void GenericLogModeConfiguration::setLogFilesPaths(const QStringList &logFilesPaths)
 {
-    d->logFilesPaths = logFilesPaths;
+    mLogFilesPaths = logFilesPaths;
 }
 
 void GenericLogModeConfiguration::setLogFilesLevels(const QList<int> &logFilesLevels)
 {
-    d->logFilesLevels = logFilesLevels;
+    mLogFilesLevels = logFilesLevels;
 }
 
-QList<LogFile> GenericLogModeConfiguration::findGenericLogFiles()
+QVector<LogFile> GenericLogModeConfiguration::findGenericLogFiles() const
 {
-    QList<LogFile> logFiles;
+    QVector<LogFile> logFiles;
 
-    if (d->logFilesPaths.size() != d->logFilesLevels.size()) {
+    if (mLogFilesPaths.size() != mLogFilesLevels.size()) {
         logDebug() << i18n("The two arrays size are different, skipping the reading of log files.");
         return logFiles;
     }
 
-    LogLevel *level;
+    LogLevel *level = nullptr;
 
-    QListIterator<QString> itString(d->logFilesPaths);
-    QListIterator<int> itInt(d->logFilesLevels);
+    QListIterator<QString> itString(mLogFilesPaths);
+    QListIterator<int> itInt(mLogFilesLevels);
 
     while (itString.hasNext()) {
-        int intValue = itInt.next();
-        QString stringValue = itString.next();
+        const int intValue = itInt.next();
+        const QString stringValue = itString.next();
 
-        if (intValue >= 0 && intValue < (int)Globals::instance().logLevels().count())
-            level = Globals::instance().logLevels().at(intValue);
-        else
-            level = Globals::instance().informationLogLevel();
+        level = Globals::instance().logLevels().value(Globals::LogLevelIds(intValue), Globals::instance().informationLogLevel());
 
         const QUrl url = QUrl::fromLocalFile(stringValue);
         if (!url.isValid()) {
