@@ -23,23 +23,23 @@
 
 #include <KLocalizedString>
 
-#include "multipleActions.h"
 #include "logMode.h"
 #include "logging.h"
+#include "multipleActions.h"
 
-#include "cupsLogMode.h"
 #include "cupsAccessLogMode.h"
+#include "cupsLogMode.h"
 #include "cupsPageLogMode.h"
 #include "cupsPdfLogMode.h"
 
-#include "cupsConfigurationWidget.h"
 #include "cupsConfiguration.h"
+#include "cupsConfigurationWidget.h"
 
 QList<LogMode *> CupsLogModeFactory::createLogModes() const
 {
     // Create the shared configuration and configuration widget between the logModes
     QSharedPointer<CupsConfiguration> logModeConfiguration = QSharedPointer<CupsConfiguration>(new CupsConfiguration());
-    CupsConfigurationWidget *logModeConfigurationWidget = new CupsConfigurationWidget();
+    auto logModeConfigurationWidget = new CupsConfigurationWidget();
 
     QList<LogMode *> logModes;
     logModes.append(new CupsLogMode(logModeConfiguration, logModeConfigurationWidget));
@@ -62,23 +62,27 @@ LogModeAction *CupsLogModeFactory::createLogModeAction() const
     bool cupsPageLogsExist = cupsPageLogMode->filesExist();
     bool cupsPdfLogsExist = cupsPdfLogMode->filesExist();
 
-    if (!cupsLogsExist && !cupsAccessLogsExist && !cupsPageLogsExist && !cupsPdfLogsExist)
+    if (!cupsLogsExist && !cupsAccessLogsExist && !cupsPageLogsExist && !cupsPdfLogsExist) {
         return nullptr;
+    }
 
-    MultipleActions *multipleActions
-        = new MultipleActions(QIcon::fromTheme(QStringLiteral(CUPS_MODE_ICON)), i18n("Cups"), cupsLogMode);
+    auto multipleActions = new MultipleActions(QIcon::fromTheme(QStringLiteral(CUPS_MODE_ICON)), i18n("Cups"), cupsLogMode);
 
-    if (cupsLogsExist)
+    if (cupsLogsExist) {
         multipleActions->addInnerAction(cupsLogMode->action());
+    }
 
-    if (cupsAccessLogsExist)
+    if (cupsAccessLogsExist) {
         multipleActions->addInnerAction(cupsAccessLogMode->action());
+    }
 
-    if (cupsPageLogsExist)
+    if (cupsPageLogsExist) {
         multipleActions->addInnerAction(cupsPageLogMode->action());
+    }
 
-    if (cupsPdfLogsExist)
+    if (cupsPdfLogsExist) {
         multipleActions->addInnerAction(cupsPdfLogMode->action());
+    }
 
     multipleActions->setCategory(LogModeAction::ServicesCategory);
 
