@@ -21,15 +21,15 @@
 
 #include "kernelLogMode.h"
 
-#include <QAction>
 #include <KLocalizedString>
 
 #include "logging.h"
 
-
 #include "kernelAnalyzer.h"
 #include "kernelItemBuilder.h"
 
+#include <QAction>
+
 KernelLogMode::KernelLogMode()
     : LogMode(QStringLiteral(KERNEL_LOG_MODE_ID), i18n("Kernel Log"), QStringLiteral(KERNEL_MODE_ICON))
 {
@@ -39,10 +39,10 @@ KernelLogMode::KernelLogMode()
 
     d->action = createDefaultAction();
     d->action->setToolTip(i18n("Display the kernel log."));
-    d->action->setWhatsThis(i18n(
-        "Displays the kernel log in the current tab. This log is only useful for users who want to know why "
-        "the Kernel does not detect their hardware or what is the cause of the last <i>kernel "
-        "panic/oops</i>."));
+    d->action->setWhatsThis(
+        i18n("Displays the kernel log in the current tab. This log is only useful for users who want to know why "
+             "the Kernel does not detect their hardware or what is the cause of the last <i>kernel "
+             "panic/oops</i>."));
 }
 
 KernelLogMode::~KernelLogMode()
@@ -55,9 +55,8 @@ Analyzer *KernelLogMode::createAnalyzer(const QVariant &options)
     return new KernelAnalyzer(this);
 }
 
-QList<LogFile> KernelLogMode::createLogFiles()
+QVector<LogFile> KernelLogMode::createLogFiles()
 {
-    QList<LogFile> logFiles;
-    logFiles.append(LogFile(QUrl::fromLocalFile(QStringLiteral("/bin/dmesg")), Globals::instance().informationLogLevel()));
+    const QVector<LogFile> logFiles{LogFile(QUrl::fromLocalFile(QStringLiteral("/bin/dmesg")), Globals::instance().informationLogLevel())};
     return logFiles;
 }
